/**********************************************************************************************
C or C++ Header-file for MEGSV86w32.DLL (Windows 32-Bit) and MEGSV86x64.DLL (Windows 64-Bit)
Copyright 2014 ME-Messysteme GmbH H.Kabelitz
1. Data types, all little-endian style:
	int : signed integer of 32 bits size
	unsigned long : unsigned integer of 32 bits size
	double : IEEE754 floating-point value of 64 bits size

2. Calling convention: __stdcall

************************************************************************************************/
#ifdef __cplusplus
extern "C"
{
#endif

#define CALLTYP __stdcall

/* Definition of error codes, as retrieved by GSV86getLastProtocollError and GSV86getLastErrorText */
#include "Errorcodes.h"

/************************************************************************************************
Definitions of constants.
Values can't be changed, since it won't have any effect on using the readily compiled library.
*************************************************************************************************/
/* Version of this DLL */
#define FILEVER_H                       1
#define FILEVER_L                       9

/* Return-codes for Simple errorcode */
#define GSV_OK 0	/*no error, without signalling information */
#define GSV_ERROR -1	/*an error occurred within the request */
#define GSV_TRUE 1	/*no error, with signalling information */

/*Constant values used by GSV86*actEx */
#define CONST_BAUDRATE	921600	/* Use this also for serial-over-Ethernet connection */
#define CONST_BUFSIZE	48000

/* Flags for parameter "flags" in GSV86activateExtended */
#define ACTEX_FLAG_HANDSHAKE	4	/* enables HW-handshake in in GSV86activateExtended */
#define ACTEX_FLAG_WAIT_EXTENDED	0x0100	/* waits longer for device-answer in GSV86activateExtended */
#define ACTEX_FLAG_STOP_TX	0x0200	/* stops continious data transmission in GSV86activateExtended */

/* Constants for GSV86getLastProtocollError and GSV86getLastErrorText */
#define ERRTEXT_SIZE 256 /* Maximum size of error text */
#define ERR_MASK_ALL 0xFC000000 /* Mask for error code types */
#define OWN_ERR_MASK 0x20000000 /*Mask, which can be or-ed with one of the well-known Windows Systen Error Code , see: MSDN:GetLastError() */
#define ERR_MSK_DEVICE 0x38000000 /*Error given by GSV-8 device, errorcode in Bits<7:0>, see GSV-8 manual */
/* This application Errorcodes. Retrieve with GSV86getLastProtocollError. See file Errorcodes.h */

/* Hardware properties of GSV-8 device */
#define	IN_CHAN_NO	8 /* Number of analogue input channels */
#define SIX_AXIS_CHAN_NUM 6	/* Number of channels of the six-axis sensor */
#define NUM_INTYPES 6	/* Number of switchable input types */

/* Object Mapping, as for GSV86getValObjectInfo */
#define VALOBJ_NUM_MAX 16	/* Arraysize for ScaleFactors and ObjMapping */
/* 1. Value type in  Bits<15:8> of ObjMapping */
#define VALTYPE_NORMAL 0	/* actual measuring value */
#define VALTYPE_MAXVAL	1	/* Maximum value */
#define VALTYPE_MINVAL	2	/* Minimum value */
/* 2. Physical type in Bits<23:16> of ObjMapping */
#define VAL_PHYS_TYPE_NOTDEF 0	/* no physical type defined (unknown) */
#define VAL_PHYS_TYPE_FORCE_X 1	/* Force in X-direction */
#define VAL_PHYS_TYPE_FORCE_Y 2	/* Force in Y-direction */
#define VAL_PHYS_TYPE_FORCE_Z 3	/* Force in Z-direction */
#define VAL_PHYS_TYPE_TORQUE_X 4	/* Torque-moment in X-direction */
#define VAL_PHYS_TYPE_TORQUE_Y 5	/* Torque-moment in Y-direction */
#define VAL_PHYS_TYPE_TORQUE_Z 6	/* Torque-moment in Z-direction */
#define VAL_PHYS_TYPE_RAW	0x10	/* Raw value of six-axis sensor (before calculation) */
#define VAL_PHYS_TYPE_TEMP	0x20	/* Temperature */

/* 	Struct definitition for convenience. ObjMapping parameter can be type-casted to this
	after return from GSV86getValObjectInfo.
	Must be packed to total size of 32 Bits, so better use with C or C++ only. */

typedef struct
{
	unsigned char ChannelNo;	/* Channel-Numbers from 1 to 8 */
	unsigned char ValueType;	/* Value type as defined above */
	unsigned char PhysicType;	/* Physical type as defined above */
	unsigned char reserved;		/* not yet used */
} OBJECT_MAPPING;
/* 3. DataType enumeration definition for GSV86getValObjectInfo,GSV86getInterfaceIdent, GSV86setValDataType parameter */
#define DATATYP_INT16	1	/* Datatype sent by GSV-8 is 16-Bit value in binary offset format */
#define DATATYP_INT24	2	/* Datatype sent by GSV-8 is 24-Bit value in binary offset format */
#define DATATYP_FLOAT	3	/* Datatype sent by GSV-8 is 32-Bit Float (scaled in physical units) */

/* Parameter of GSV86getInterfaceIdentity */
#define SET_STOP_MV_TX	1	/* StopPermTX parameter: Disable permanent measuring value transmission */
#define SET_START_MV_TX	2	/* StopPermTX parameter: Enable permanent measuring value transmission */

/* Constants for GSV86getMode and GSV86setMode Flag-Parameter Mode*/
#define SIX_AXIS_SENSOR_ACTIVE 0x01 /* Six-axis sensor (=FT-sensor) calculation enabled */
#define ANALOG_FILTER_AUTO 0x02 /* Analog input filter's cut-off frequency set automatically according to data rate */
#define MODE_MAXIMUM 0x04 /* determine maximum- and minimum value */
#define MODE_NOISECUT 0x08 /* if =1: values below noiseCutThreshold are set to 0 */
#define ALL_WRITES_BLOCKED 0x80 /* all write / set commands are blocked */

/* Constants for GSV86getTXmode and GSV86setTXmode Flag-Parameter*/
#define TX_OFF_VOLATILE 0x01 /* permanent measured value transmission actually off (not stored in EEPROM)*/
#define TX_OFF_NONVOLAT	0x02 /* permanent measured value transmission permanent off (stored in EEPROM)*/
#define TX_MAXVALUE 0x04 /* values in measured vals frame are maximum values */
#define TX_MINVALUE 0x08 /* values in measured vals frame are minimum values */
#define THRESH_VALTYPE_FLOAT 0x10 /* values for noiseCutThreshold and DoutThreshold are stored as float */

/*Type enums (constants) for GSV86readFTsensorCalValue */
#define SENSORCAL_TYP_SERNO 0 /* Sensor serial number. Type-exeption: u32 not float! */
#define SENSORCAL_TYP_MATRIX_NORM 1 /* scaling of values in matrix (=1 for normalized matrix values)*/
#define SENSORCAL_TYP_MATRIX 2 /* 6-axis sensor coefficients 6x6 =36 matrix */
#define SENSORCAL_TYP_OFFSET 3 /* mechanical offsets, 3 values Lx,Ly,Lz */
#define SENSORCAL_TYP_MAXVAL 4 /* sensor nominal maximum values, 6vals Fx,Fy,Fz,Mx,My,Mz */
#define SENSORCAL_TYP_INSENS 5 /* Input sensitivity of amp wich matrix vals were obtained (=1 for normalized matrix values)*/
#define SENSORCAL_TYP_ZEROVAL 6 /* Zero signal values of unloaded sensor */
#define SENSORCAL_MATRIX_NORM_DEF 5.0 /* default value for SENSORCAL_TYP_MATRIX_NORM */
#define SENSORCAL_INSENS_DEF 2.0 /* default value for SENSORCAL_TYP_INSENS */
#define SENSORCAL_ZEROVAL_DEF 0.0  /* default value for SENSORCAL_TYP_ZEROVAL */
#define SENSORCAL_OFFSET_DEF 0 /* default value for SENSORCAL_TYP_OFFSET */
#define SENSORCAL_TYP_TEDS_MEM 0x80	/*Memory type-offset for TEDS memory (reserved)*/
#define SENSORCAL_TYP_EEPROM_MEM 0 /*Memory type-offset for EEPROM memory*/
#define SENSORCAL_VECTOR_SIZE 6
#define SENSORCAL_MATRIX_SIZE	36
#define SENSORCAL_OFFSET_SIZE	3
#define SENSORCAL_MAXVAL_SIZE	6

/*serial number constants */
#define SER_NO_SIZE	8
#define SER_NO_CHAR_SIZE SER_NO_SIZE+1	/*inclusive termination */
#define SERNO_MIN 1
#define SERNO_MAX 99999999

/* Constants for GSV86getInTypeRange, GSV86getAllInTypesRanges and GSV86setInType */
#define MAX_INPUT_TYPES_NUM 10	/* Maximum possible number of input types.
	(bigger than max. existent type-num, for future compatibiliy) */
#define INTYP_BRIDGE_US875 0	/* Input-Type Bridge at Vexcitation= 8.75V */
#define INTYP_BRIDGE_US5 1	/* Input-Type Bridge at Vexcitation= 5V */
#define INTYP_BRIDGE_US25 2	/* Input-Type Bridge at Vexcitation= 2.5V */
#define INTYP_SE10 3		/* Input-Type single-endend +-10V */
#define INTYP_PT1000	4	/* Input-Type Temperature-Sensor PT1000 */
#define INTYP_TEMP_K	5	/* Input-Type Temperature-Sensor Type-K (reserved)*/

/* Constants for GSV86getUnitText and GSV86setUnitText */
#define UNIT_WIDTH 8	/* maximum width of unit text array incl. termination*/
/* Bits<7:0> of Code parameter. Can be ORed with Bit<23:8> constants */
#define ACTIVE_UNIT_ANY 0x00 /*GSV86getUnitText: Read active unit. GSV86setUnitText: Set and activate any unit */
#define USER_UNIT_1 0x01 /*GSV86getUnitText: Read user defined unit string 1. 
			GSV86setUnitText: Set and activate user defined unit string 1. */
#define USER_UNIT_2 0x02 /*GSV86getUnitText: Read user defined unit string 2. 
			GSV86setUnitText: Set and activate user defined unit string 2. */
#define SET_FIXED_UNIT	0x10 /*GSV86setUnitText: Set and activate fixed unit (UnitNo set) */
#define WRITE_USER_UNIT_1 0x11 /*GSV86setUnitText: Write user unit string 1 (not activated) */
#define WRITE_USER_UNIT_2 0x12 /*GSV86setUnitText: Write user unit string 2 (not activated) */
/* Bits<23:0> of Code parameter. Can be ORed with Bit<7:0> constants */
#define ANSI_CODEPAGE 0x00000000 /* ANSI 8-Bit coded */
#define ASCII_ONLY	0x00000100 /* Use ASCII 7-Bit only */
#define DOS_CODEPAGE_437 0x0001B500 /* DOS/Windows Codepage 437 */
#define WIN_CODEPAGE_1252 0x0004E400 /* Windows Codepage 1252 */

/* Constants for digital filters GSV86getDfilterOnOff and GSV86setDfilterOnOff */
#define FILT_TYPE_IIR	0	/* Mask or for IIR-Type. */
#define FILT_TYPE_FIR	0x80	/* Mask or for FIR-Type. See function description for details*/
#define FILT_TYPE_IIR_LP	0x04	/* IIR low pass, 4th order*/
#define FILT_TYPE_IIR_HP	0x14	/* IIR high pass, 4th order*/
#define FILT_TYPE_IIR_BP	0x24 	/* IIR band pass, 4th order*/
#define FILT_TYPE_IIR_BS	0x34 	/* IIR band stop, 4th order*/
#define FILT_TYPE_UNCONFIG	0x00	/* Filter has nor been configured */
#define FILT_ORDER_MSK		0x0F	/* Mask for filter order */
#define FILT_ORDER_IIR	4 /* As by now, filter order is constant for IIR filter */
#define FILT_MAXORDER_FIR 14 /* Maximum FIR filter Order */
#define FILT_MINORDER_FIR 4	/* Minimum FIR filter Order */
#define FILT_COEFFNUM_FIR 8 /* Because a0=a7, a1=a6... coeff. number is order/2 */
#define FILT_CHARACT_MSK	0x70	/* Mask for filter characteristic (LP,HP,BP,BS) */
#define FILT_CHARACT_LP	0x00	/* low pass */
#define FILT_CHARACT_HP	0x10	/* high pass */
#define FILT_CHARACT_BP	0x20	/* band pass */
#define FILT_CHARACT_BS	0x30	/* band stop */
#define FILT_CHARACT_COMB 0x40 /* comb filter (FIR only) */
#define FILT_IDX_MSK_B_COEFF 0x10 /*Mask for IIR index parameter for b coefficients */
#define FILT_FCUT_RATIO_MAX 0.5f	/* maximum ratio for Fcutoff/Fs */
/* Constants for GSV86simulateDfilter. May be ORed with FILT_TYPE_FIR */
#define SIMUL_DFILT_FREQ_RESPONSE 1 /* simulate frequency response (frequency domain)*/
#define SIMUL_DFILT_STEP_RESPONSE 2 /* simulate step response (time domain)*/

/* Constants for analogue filter */
#define FDATA_MAX_FG28HZ 80	/* With SetAnalogFilterAuto: Below this data rate filter is set to 28Hz cutoff */
#define FDATA_MAX_FG1KHZ 3000 /* With SetAnalogFilterAuto: Below this data rate filter is set to 850Hz cutoff */
#define ANAFILT_LOW	28	/* lowest cut-off frequency of analogue input filter (switchable) */
#define ANAFILT_MID	850	/* middle cut-off frequency of analogue input filter (switchable) */
#define ANAFILT_HIGH	12000 /* highest cut-off frequency of analogue input filter (fixed) */

/* Constants for analog output */
#define AOUT_TYPE_0_10V 0	/* 0..10V  */
#define AOUT_TYPE_10_10V 1	/* -10..10V */
#define AOUT_TYPE_0_5V 2	/* 0..5V */
#define AOUT_TYPE_5_5V 3	/* -5..5V */
#define AOUT_TYPE_4_20A 4	/* 4..20mA */
#define AOUT_TYPE_0_20A 6	/* 0..20mA */
/* Mode: Flag value as follows: */
#define AOUT_ACTIVE_M_VALUES 0 /* Output is on and follows the corresponding measuring value input. */
#define AOUT_MODE_DIRECT 1 /*Output is on, but does NOT react on measuring values,
				but is direcly settable with GSV86writeAoutDirect */
#define AOUT_MODE_OFF 2 /* Output is off and high-impedance. */
#define AOUT_IX_MAX 8	/* 8 Analogue Voltage/current outputs. */
#define AOUT_SCALE_IX_MAX 9 /* No. 9 for special-version (freq. output) */

/* Constants for GSV86getEquipment */
#define HAS_ADC 0x01
#define HAS_ETHERCAT 0x02
#define HAS_LCD 0x04
#define HAS_TEDS 0x08
#define HAS_DIGI_IO 0x10
#define HAS_ANALOG_OUT 0x40
#define HAS_SERIAL 0x80
#define HAS_FREQ_OUT 0x100
#define HAS_AIN_MCU 0x200
#define HAS_SIXAXIS 0x400
#define HAS_CANOPEN 0x800

/* Constants for DIOtype */
#define DIO_IN_GENERALPURPOSE 0x04
#define DIO_IN_QEI_ANY 0x08
#define DIO_IN_TARE_SINGLE 0x10
#define DIO_IN_TARE_ALL 0x20
#define DIO_IN_RESET_MAXMIN 0x40
#define DIO_IN_TRIG_SEND_VAL 0x80
#define DIO_IN_TRIG_SEND_MAXVAL 0x100
#define DIO_IN_TRIG_SEND_MINVAL 0x200
#define DIO_IN_TRIG_SEND_AVGVAL 0x400
#define DIO_IN_TRIG_SEND_VAL_WHILE_HI 0x800
#define DIO_OUT_GENERALPURPOSE 0x1000
#define DIO_THRESHOLD_WINDOWCOMP_MASK 0x2000
#define DIO_OUT_THRESHOLD_MAXVAL 0x14000
#define DIO_OUT_THRESHOLD_MINVAL 0x18000
#define DIO_OUT_THRESHOLD_ANYVAL 0x10000
#define DIO_INVERT_MASK	0x800000

/* Constants for GSV86readCANsettings / GSV86setCANsettings */
#define CAN_SER_CMD_ID 0
#define CAN_SER_ANSW_ID 1
#define CAN_SER_MV_ID 2
#define CAN_SER_MULTI_ID 3
#define CAN_BAUDRATE 4
#define CAN_FLAGS 5
#define CANOPEN_NODEID 6
#define CAN_FLAGMASK_ONOFF 1
#define CAN_FLAGVAL_ON 0
#define CAN_FLAGVAL_OFF 1
#define CAN_FLAGMASK_PROT 2
#define CAN_FLAGVAL_CANOPEN 2
#define CAN_FLAGVAL_CANSER 0

/* Constant macros for use with Communication interface descriptor functions:
	GSV86readInterfaceSetting
	GSV86writeInterfaceSetting
	GSV86readBasicInterfSettings
	GSV86readAllInterfSettings */
/* Interface Physical Layer protocol enumeration */
#define INTF_PHY_TYP_V24 1	/* RS232 with V24 voltage levels */
#define INTF_PHY_TYP_232TTL 2	/* RS232 with 3.3V / 0V voltage levels */
#define INTF_PHY_TYP_USB 3	/* USB (with CDC) */
#define INTF_PHY_TYP_CAN 4	/* CAN bus */
#define INTF_PHY_TYP_ETH 5	/* 100BaseT "Ethernet" */
/* Interface Application Layer protocol enumeration */
#define INTF_APP_TYP_GSV68 0x00000001L /* ME propretary "GSV6/8" interface, used by this DLL */
#define INTF_APP_TYP_CANOPEN 0x00000002L /* CANopen */
#define INTF_APP_TYP_ETCOE 0x00000003L /* EtherCAT CoE */
#define INTF_APP_TYP_MONI 0x00000004L /* Text-based commands "Monitor", GSV-6 only */
/* The flags-value of basic interface setting */
#define INTF_T1_FLG_ACT 1 /* Flag (-mask) indicating that interface is enabled */
#define INTF_T1_FLG_RXACT 1 /* Flag (-mask) indicating that receiving commands is enabled */
#define INTF_T1_FLG_TXACT 2 /* Flag (-mask) indicating that transmitting data is enabled */
#define INTF_T1_FLG_TXRX_ACT 3 /* Flag (-mask) indicating that transmit and receive is enabled */
#define INTF_T1_FLG_WRACC 4 /* Flag (-mask) indicating that write commands are allowed */
#define INTF_T1_MV_BINOFS 8 /* Flag (-mask) indicating that integer measuring values have binary offset formal (sign bit inverted) */
#define INTF_T1_FLG_SWITCHABLE 0x10000 /* Flag (-mask) indicating that interface can be disabled (then enabled) */
#define INTF_T1_FLG_ADRESSABLE 0x20000 /* Flag (-mask) indicating that interface uses device or service address/ID */
#define INTF_T1_FLG_ADRES_CHANGE 0x40000 /* Flag (-mask) indicating that device / service address/ID can be changes by command interface*/
/* Data/Setting type 2 meaning enumeration */
#define INTF_DSCTYP_FLAGS 0  /* Flag value of basic interface setting */
#define INTF_DSCTYP_FLG_SETMSK 1 /* Mask for setting a bit in the Flag value of the basic setting =1:Flag at this pos. can be set*/
#define INTF_DSCTYP_FLG_CLRMSK 2 /* Mask for clearing a bit in the Flag value of the basic setting =1:Flag at this pos. can be cleared*/
#define INTF_DSCTYP_MUTEXCLUSIV 3 /* Ordinal number of other interfaces, that this exist in a mutual exclusive manner. Upto 4 in 4 Bytes, beginning with LSByte*/
#define INTF_DSCTYP_ACTBAUD 4 /* Baud Rate actually set, in Bits/s */
#define INTF_DSCTYP_BAUD_AVAIL 5 /* Baud rate existent, in Bits/s */
#define INTF_DSCTYP_NUM_SERVID 6 /* Number of IDs of device or servicve, used with field bus interfaces */
#define INTF_DSCTYP_SERVID_CAN_IN 7 /* CAN-ID for Host->Device commands, used with "GSV68 CAN-serial" */
#define INTF_DSCTYP_SERVID_CAN_OUT 8 /* CAN-ID for Device->Host command answers, used with "GSV68 CAN-serial" */
#define INTF_DSCTYP_SERVID_CAN_CV 9  /* CAN-ID for Device->Host measuring value frames, used with "GSV68 CAN-serial" */
#define INTF_DSCTYP_SERVID_CAN_CAST 10 /* CAN-ID for Host->Devices multicast messages, used with "GSV68 CAN-serial" */
#define INTF_DSCTYP_SERVID_CANO_NODE 11 /* CANopen Node-ID, used with CANopen aplication protocol */
#define INTF_DSCTYP_DEVSTATE 16 /* Device state, used with fieldbus application protocols */
	#define INTF_FB_STAT_OFF 0 /* Data-value for INTF_DSCTYP_DEVSTATE if Interface is off */
	#define INTF_FB_STAT_INIT 2 /* Data-value for INTF_DSCTYP_DEVSTATE if device is in init or stopped state */
	#define INTF_FB_STAT_PO 4 /* Data-value for INTF_DSCTYP_DEVSTATE if device is in pre-operational state */
	#define INTF_FB_STAT_SO 8 /* Data-value for INTF_DSCTYP_DEVSTATE if device is in safe operational state (EtherCAT) */
	#define INTF_FB_STAT_O 12 /* Data-value for INTF_DSCTYP_DEVSTATE if device is in operational state */
#define INTF_DSCTYP_CANO_TX_TIME 17 /* CANopen Transmission Type (Bits<31:24>) and Event timer (Bits<15:0>) */
#define INTF_DSCTYP_CANO_INH_HB 18 /* CANopen Inhibit time (Bits<31:16>) and Heartbeat time (Bits<15:0>) */
#define INTFT2_WR 0x80 /* Flag value indicating that a value is writable. ORed with data type enum */

#pragma once

/************************************************************************************
Exported functions Prototypes

/*************************************************************************************
	Get DLL version Number
--------------------------------------------------------------------------------------
 \in none
 \return Version Number High in Bits<31:16>, Version number Low in Bits<15:0>
 Example: Version 1.1.00.32: return value 0x00010001 = d65537
 Remark: 3rd and 4th number of version ressource NOT part of return value
--------------------------------------------------------------------------------------
 OrdinalNo: 1
 Device access: No
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
unsigned long CALLTYP GSV86dllVersion(void);

/*************************************************************************************
	Opens a GSV8/GSV6 on a (V)COM-port, with all necessary ressources.
	Simplified Version of GSV86activeteExtended, with:
	Bitrate=CONST_BAUDRATE, BufSize=CONST_BUFSIZE, flags=0
--------------------------------------------------------------------------------------
 \in	ComNo: 	Number of Comport to be opened
 	
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if ComPort could not be opened or device was not found.
 If =GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 2
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
**************************************************************************************/
int CALLTYP GSV86actExt(int ComNo);

/*************************************************************************************
	Opens a GSV8/GSV6 on COM-port, specified by parameters, with all necessary ressources.
--------------------------------------------------------------------------------------
 \in	ComNo: 	Number of Comport to be opened
 	Bitrate: Bits per second. Allowed values: 9600,19200,38400,57600,115200,230400,460800,921600
 		Must match device setting with Ethernet-Xport, RS232 and RS422 only;
 		but can be any of above values with USB-CDC - value will be discarded.
 	BufSize: Size of the buffer, given in number of measuring values.
 		In this buffer measuring values are stored by the reading thread of this DLL
 		and from where values are read by GSV86read/GSV86readMultiple.
 		Size is in Measuring values per channel-object; e.g. with MappedObjectNum=8 and BufSize=30000,
 		8 buffers are allocated, and each has a capacity of 30000 measuring values.
 	flags:	Openes with special settings, specified by this flags. Can be ORed together.
 		ACTEX_FLAG_HANDSHAKE: if set, opens the port with hardware-handshake (RTS-CTS)
		ACTEX_FLAG_WAIT_EXTENDED: waits longer for device-answer
		ACTEX_FLAG_STOP_TX stops continious data transmission
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if ComPort could not be opened or device was not found.
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 4
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
**************************************************************************************/
int CALLTYP GSV86activateExtended(int ComNo, unsigned long Bitrate, unsigned long BufSize, unsigned long flags);

/*************************************************************************************
	Get Last Error Code
	Can be called after another function returned GSV_ERROR.
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return One of the following:
 1. Direct System Error Codes (http://msdn.microsoft.com/en-us/library/ms681381%28VS.85%29.aspx),
 retrieved by GetLastError(), which was called by previously failed function.
 Only if GSV86actEx/GSV86activateExtended failed before hardware were accessed.
 2. System Error Codes as above ORed with OWN_ERR_MASK (0x20000000)
 3. Error code as defined above. Range: 0x30000001..0x3000FFFF
 4. Error code thrown by GSV-8 device, ORed with 0x38000000. Range: 0x38000001..0x380000FF. See GSV-8 manual for details.
--------------------------------------------------------------------------------------
 OrdinalNo: 6
 Device access: No
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getLastProtocollError(int ComNo); //http://msdn.microsoft.com/en-us/library/ms681381(VS.85).aspx

/*************************************************************************************
	Get Last Error Code and error describing text
	Can be called after another function returned GSV_ERROR.
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 ErrText: pointer to ASCII coded 8-Bit char array of size 256 chars, where error text is written to.
 \return One of the following:
 1. Direct System Error Codes (http://msdn.microsoft.com/en-us/library/ms681381%28VS.85%29.aspx),
 retrieved by GetLastError(), which was called by previously failed function.
 Only if GSV86actEx/GSV86activateExtended failed before hardware were accessed.
 2. System Error Codes as above ORed with OWN_ERR_MASK (0x20000000)
 3. Error code as defined in Errorcodes.h. Range: 0x30000001..0x3000FFFF
 4. Error code thrown by GSV-8 device, ORed with 0x38000000. Range: 0x38000001..0x380000FF. See GSV-8 manual for details.
--------------------------------------------------------------------------------------
 OrdinalNo: 5
 Device access: No
---------------------------------------------------------------------------------------
 \revision date: 27.04.2015 14:12
 **************************************************************************************/
int CALLTYP GSV86getLastErrorText(int ComNo, char* ErrText);

/*************************************************************************************
	Clear and reset all DLL Buffers
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if 
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 8
 Device access: No
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86clearDLLbuffer(int ComNo);

/*************************************************************************************
	Get device model and communication interface information
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	StopPermTX: if =1, The permanent mesuring data transmission will be stopped.
 		if =2, The permanent mesuring data transmission will be started.
 \out	*NumOfIntfDescr: pointer to total number of communication interfaces and their descriptors
 	*ThisInterfNo: pointer to Index of this communicating interface in the descriptor array
 	*WriteProtection: pointer: =0: no write protection, =2: write protection enabled
 	*MValDataType: pointer to Measuring value type: =1: DATATYP_INT16, =2: ~24, =3: DATATYP_FLOAT
 	*MValPermanenTX: pointer: =1 permanent mesuring value transmission on, =0: no permanent val.tx
 	*NumObjInMVframe: pointer to Number of objects in mesuring value frame
 	*ThisDeviceModel: pointer to Model No of device attached. GSV-8: =8
 	*ThisProtocol: pointer to General interface type. =1 for serial
 \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if 
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 7
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 30.09.2015 12:02
 **************************************************************************************/
int CALLTYP GSV86getInterfaceIdentity(int ComNo, int StopPermTX, int* NumOfIntfDescr, int* ThisInterfNo, int* WriteProtect,
		int* MValDataType, int* MValPermanenTX, int* NumObjInMVframe, int* ThisDeviceModel, int* ThisProtocol);

/*************************************************************************************
	Clear and reset device measuring values buffer
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if 
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 9
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86clearDeviceBuf(int ComNo);

/*************************************************************************************
	Get number of measuring values in DLL buffer(s)
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: =0: get lowest buffer filling
 		=1..NumMappedObjects: get buffer filling for specified object
 		=NumMappedObjects+1: get highest buffer filling
 	Remark: Different buffer fillings can only occur, if GSV86read or
 		GSV86readMultiple with parameter Chan >0 is used.
 		If GSV86readMultiple with parameter Chan=0 is used only, all buffers have the
 		same filling.
 \return: Number of values in specified buffer, or
 		GSV_ERROR if an error occurred.
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 10
 Device access: No
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86received(int ComNo, int Chan);

/*************************************************************************************
	Read one measuring value of one (channel-) object
--------------------------------------------------------------------------------------
 \in 	ComNo: 	Number of Device Comport
 	Chan: Number of Object (channel, respectively) to read. Range: 1..NumMappedObjects
 	out: Pointer to one double value, were the measuring value is written to
 \return: 	GSV_OK,if no value was read (buffer empty), or 
 		GSV_TRUE if a value was read, or
 		GSV_ERROR if an error occurred
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 12
 Device access: No
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86read(int ComNo, int Chan, double* out);

/*************************************************************************************
	Reads whole Array of values in dll-value-buffer(s)
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan:	=0: Read all existent (channel-)objects
 		=1..NumMappedObjects: Read values of specified object
 	*out:	Pointer to (one-dimensional) array of double, where mesuring values
 		are be written to (if return-value =GSV_TRUE).
 		Important: Array size must be greater or equal <count>!
 	count:	Total maximum number of values to read.
 		If Chan=0, count must be dividible by NumMappedObjects.
 	*valsread: Pointer to int value, where the actual number of values written into *out is stored.
 	*ErrFlags: Pointer to int value, where measuring-value-related error flags given by device are stored
 		May be set to NULL, if not used.
 \return Simple errorcode: GSV_OK, if (at least one) buffer is emty and no values were read, or 
 	GSV_TRUE if value(s) were read, or
 	GSV_ERROR if an (internal) error occurred. Remark: Value-related error flags set by device
 		have no impact on the return value (i.e. *ErrFlags !=0 : return GSV_TRUE)
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
-----------------------------------------------------------------------------------------------
Reads whole array of measuring values in dll-value-buffer(s), if returned GSV_TRUE.
Reads up to <count> values and writes number of values, which were really read, into <valsread>. <count> must be >0.
If resulting <valsread> is smaller than <count>, the whole buffer (the smallest, if Chan=0) was read.
If Chan=0: Reads whole Array of all channel-objects into the array of double-type,
where <out> points to. <count> must be dividible by <NumMappedObjects> (determine NumMappedObjects with GSV86getValObjectInfo).
Assuming Chan=0 and NumMappedObjects=8, <out> is sorted as follows:
Obj1 in n*8, Obj2 in (n*8)+1, Obj3 in (n*8)+2, and so on, Obj8 in (n*8)+7; with n= {0...(<valsread> /8)-1}
Example: Assumed, Chan=0, count >=16 and NumMappedObjects=8, and <valsread> results =16,
the content of <out> is, beginning with index 0:
oldObj1,oldObj2,...,oldObj8,newObj1,newObj2,...,newObj8
If Chan={1..NumMappedObjects}: Reads whole Array of specified object.
Oldest value is at index 0 (base) of <out>-array, newest at <valsread>-1.
--------------------------------------------------------------------------------------
 OrdinalNo: 14
 Device access: No
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86readMultiple(int ComNo, int Chan, double *out, int count, int* valsread, int* ErrFlags);

/*************************************************************************************
	Starts GSV-4 value transmission, if stopped before.
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 \Remark: starts GSV-4 value transmission. State not saved in device non-volatile memory.
--------------------------------------------------------------------------------------
 OrdinalNo: 16
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86startTX(int ComNo);

/*************************************************************************************
	Stopps GSV-4 value transmission, if started before.
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if 
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 \Remark: stops GSV-4 value transmission. State not saved in device non-volatile memory.
--------------------------------------------------------------------------------------
 OrdinalNo: 18
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86stopTX(int ComNo);

/*************************************************************************************
	Close COMport and free all associated dll-ressources
	Should be called at program (i.e. dll caller'd trmination;
	Must be called before re-opening a GSV-8 at the same COMport
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 20
 Device access: No
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86release(int ComNo);

 
 /*************************************************************************************
	Read device serial number
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return Serial-No or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 70
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getSerialNo(int ComNo);
 
/*************************************************************************************
	Get information Flags on value transmission and command communication
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Index:	=0: Read TXmode-flags. Return value defined as follows:
 			Bit0: =1: Measuring value transmission is temorarily stopped (by GSV86stopTX)
 			      =0: Permanent measuring value transmission active
 			Bit1: =1: Measuring value transmission is stopped (stored in non-volatile memory)
 			    =0: By parameterization (non-volatile memory), permanent value transmission is active
 			Remark: Get this information simplier by calling GSV86isValTXpermanent
 			Bit 6: =1: Serial Port (Ethernet) has no write access
 			       =0: Serial Port (Ethernet) may have write access (depending on other settings)
 			Bit 7: =1: USB Port has no write access
 			       =0: USB Port may have write access (depending on other settings)
 			Remark: Get this information simplier and reliably by calling GSV86getWriteAccess
 		=1: Read measuring value type. Return value defined as follows:
 			=1: Measuring value is a 16-Bit integer in binary offset format, unscaled raw value
 			=2: Measuring value is a 24-Bit integer in binary offset format, unscaled raw value
 			=3: Measuring value is a IEEE754 float, 32 bit size, scaled in physical units
 			Remark: Value type can also be determined with GSV86getValObjectInfo
 		=2: Read input channel numbering information. Return value defined as follows:
 			Bits<7:0>: lowest input channel number (constant =1 for GSV-8 by now)
 			Bits<15:8>: highest input channel number (constant =8 for GSV-8 by now)
 \return Informational value as defined above, or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 22
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getTXmode(int ComNo, int Index);

/*************************************************************************************
	Set Value transmission type and flags
--------------------------------------------------------------------------------------
 \in 	ComNo: 	Number of Device Comport
 	Index:	=0: Set TXmode-flags.
 		=1: Set measuring value type.
 	TXmode: If Index=0 (set TXmode-flags), defined as follows:
 		Bit0: =1: Measuring value transmission is temorarily stopped (not stored in non-volatile memory)
 			Remark: Set this easier by calling GSV86stopTX.
 		      =0: Permanent measuring value transmission active (stored in non-volatile memory).
 		      Remark: Set this easier by calling GSV86startTX.
 		Bit1: =1: Measuring value transmission is stopped (stored in non-volatile memory)
 		      =0: Permanent value transmission is active (stored in non-volatile memory)
 		Remark: Write access bits are read-only.
 		If Index=1 (set measuring value type), defined as follows:
 			=1: Measuring value is a 16-Bit integer in binary offset format, unscaled raw value
 			Reamark: Set this easier by calling GSV86setValDataType
 			=2: Measuring value is a 24-Bit integer in binary offset format, unscaled raw value
 			=3: Measuring value is a IEEE754 float, 32 bit size, scaled in physical units
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 24
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 11-19-2014
 **************************************************************************************/
int CALLTYP GSV86setTXmode(int ComNo, int Index, unsigned long TXmode);

/*************************************************************************************
	Get information on permanent measuring value transmission
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return GSV_OK, if permanet value transmission is actually stopped
 	GSV_TRUE, if permanet value transmission is actually active
 	or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 28
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 11-19-2014
 **************************************************************************************/
int CALLTYP GSV86isValTXpermanent(int ComNo);

/*************************************************************************************
	Get information on device parameter write access via this interface
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return GSV_OK, if this interface doesn't have write access
 	GSV_TRUE, if this interface has write access
 	or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 60
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 11-19-2014 TODO
 **************************************************************************************/
int CALLTYP GSV86getWriteAccess(int ComNo);

/*************************************************************************************
	Set measuring value data type sent by device
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Datatype: Data type enumeration, defines as follows:
 	#define DATATYP_INT16	0 Datatype sent by GSV-8 is 16-Bit raw value in binary offset format
	#define DATATYP_INT24	1 Datatype sent by GSV-8 is 24-Bit raw value in binary offset format
	#define DATATYP_FLOAT	2 Datatype sent by GSV-8 is 32-Bit Float, scaled in physical units
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 62
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 11-19-2014
 **************************************************************************************/
int CALLTYP GSV86setValDataType(int ComNo, int Datatype);

/*************************************************************************************
	Get GSV-8 firmware version
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return Firmware version:
 	Bits<31:16>: Higher number of firmware version
 	Bits<15:0>: Lower number of firmware version
 	or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 26
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86firmwareVersion(int ComNo);

/*************************************************************************************
	Get measuring value scaling factor
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
     Chan: Number of input channel to get scaling factor. Range: 1..8
     *Norm: Pointer to one variable of type double, where scaling factor is written to.
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 \remark: Scaling factor and raw measuring value is the float measuring value product,
 	if six-axis sensor is not used.
--------------------------------------------------------------------------------------
 OrdinalNo: 28
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86readUserScale(int ComNo, int Chan, double* Norm);

/*************************************************************************************
	Set measuring value scaling factor
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: Number of input channel to set scaling factor. Range: 0..8. 0: set all channels.
 	Norm: Scaling factor.
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 30
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86writeUserScale(int ComNo, int Chan, double Norm);

/*************************************************************************************
	Get Mode flags
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return Mode-Flags:
 	#define SIX_AXIS_SENSOR_ACTIVE 0x01
	#define ANALOG_FILTER_AUTO 0x02
	#define MODE_MAXIMUM 0x04
	#define MODE_NOISECUT 0x08
	#define ALL_WRITES_BLOCKED 0x80
 or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 32
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getMode(int ComNo);

/*************************************************************************************
	Set Mode flags
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 Mode: Flags for device operation (channel independent or valid for all channels)
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 34
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86setMode(int ComNo, unsigned long Mode);

/*************************************************************************************
	Get Mode: Six-Axis sensor active
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return: GSV_OK,if Six-axis sensor disabled, GSV_TRUE if enabled, or
 GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 134
 Device access: Yes (Cmd. 0x26)
---------------------------------------------------------------------------------------
 \revision date: 30.04.2015 14:14
 **************************************************************************************/
int CALLTYP GSV86getFTsensorActive(int ComNo);

/*************************************************************************************
	Set Mode: Six-Axis sensor active
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 OnOff: =1 to enable Six-axis sensor, =0 to disable it
 \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 135
 Device access: Yes (Cmd. 0x26, 0x27)
---------------------------------------------------------------------------------------
 \revision date: 30.04.2015 14:14
 **************************************************************************************/
int CALLTYP GSV86setFTsensorActive(int ComNo, int OnOff);

/*************************************************************************************
	Get Mode: Automatic selection of Analog filter
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return: GSV_OK,if Analog-filter-auto is disabled, GSV_TRUE if enabled, or
 GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 136
 Device access: Yes (Cmd. 0x26)
---------------------------------------------------------------------------------------
 \revision date: 30.04.2015 14:14
 **************************************************************************************/
int CALLTYP GSV86getModeAfilterAuto(int ComNo);

/*************************************************************************************
	Set Mode: Automatic selection of Analog filter
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 OnOff: =1 to enable Automatic selection of Analog (anti-aliasing-) filter according to
 	the configured data rate, =0 to disable it
 \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 137
 Device access: Yes (Cmd. 0x26, 0x27)
---------------------------------------------------------------------------------------
 \revision date: 30.04.2015 14:14
 **************************************************************************************/
int CALLTYP GSV86setModeAfilterAuto(int ComNo, int OnOff);

/*************************************************************************************
	Get Mode: Noise-cut threshold active
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return: GSV_OK,if Noise-cut threshold disabled, GSV_TRUE if enabled, or
 GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 138
 Device access: Yes (Cmd. 0x26)
---------------------------------------------------------------------------------------
 \revision date: 30.04.2015 14:14
 **************************************************************************************/
int CALLTYP GSV86getModeNoiseCut(int ComNo);

/*************************************************************************************
	Set Mode: Noise-cut threshold active
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 OnOff: =1 to enable Six-axis sensor, so that measuring values between NoiseCutThreshold
 	and -NoiseCutThreshold are set to 0.
 	=0: to disable Noise-cut threshold
 \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 139
 Device access: Yes (Cmd. 0x26, 0x27)
---------------------------------------------------------------------------------------
 \revision date: 30.04.2015 14:14
 **************************************************************************************/
int CALLTYP GSV86setModeNoiseCut(int ComNo, int OnOff);

/*************************************************************************************
	Get Mode: Maximum / Minimum measuring value determination active
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return: GSV_OK,if Maximum / Minimum mode disabled, GSV_TRUE if enabled, or
 GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 145
 Device access: Yes (Cmd. 0x26)
---------------------------------------------------------------------------------------
 \revision date: 19.05.2015 22:02
 **************************************************************************************/
int CALLTYP GSV86getModeMaxMin(int ComNo);

/*************************************************************************************
	Set Mode: Enable Maximum / Minimum measuring value determination
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 OnOff: =1 to enable Maximum / Minimum measuring value determination.
 	Result can be retrieved with GSV86getMaxMinValue. 
 	=0: to disable Maximum / Minimum mode
 \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 146
 Device access: Yes (Cmd. 0x26, 0x27)
---------------------------------------------------------------------------------------
 \revision date: 19.05.2015 22:04
 **************************************************************************************/
int CALLTYP GSV86setModeMaxMin(int ComNo, int OnOff);

/*************************************************************************************
	Get Information about the masuring value frame
	and the measuring value's (read by GSV86read/GSV86readMultiple) interpretation.
	Typically used once before mesuring loop has started and after NormFactor(s)
	or Mode-States had changed.
--------------------------------------------------------------------------------------
 \in 	ComNo: 	Number of Device Comport
 	ScaleFactors: Pointer to array of double with size = 16.
 		If pointer-value is not NULL, the functions writes Factors into
 		indices 0.. (NumberOfMappedObjects-1), with which
 		the corresponding measuring value-objects should be multiplied in order to get
 		values that are scaled in physical units.
 	ObjMapping: Pointer to array of concatenated enumerations with size = 16.
 		If pointer-value is not NULL, the functions writes into indices 0.. (NumberOfMappedObjects-1)
 		the mapping information of the corresponding measuring-value-objects.
 		This Mapping Info is a quasi-struct and defined as follows:
 		LowByte, Bits<7:0>: Amplifiers input channel-Number of corresponding value-object.
 			Range is 1 to 8.
 		Bits<15:8>: Value-Type of corresponding value-object, defined as follows:
	 		NORMAL=0x00: The value-object is an actual value
	 		MAX_VAL=0x01:  The value-object is a maximum value
	 		MIN_VAL=0x02:  The value-object is a minimum value
 		Bits<23:16>:
 			Physical type corresponding value-object, defined as follows:
 			0x00: No physical type defined
 			0x01: Force in X direction (mainly with Six-axis sensors)
 			0x02: Force in Y direction (mainly with Six-axis sensors)
 			0x03: Force in Z direction (mainly with Six-axis sensors)
 			0x04: Torque in X direction (mainly with Six-axis sensors)
 			0x05: Torque in Y direction (mainly with Six-axis sensors)
 			0x06: Torque in Z direction (mainly with Six-axis sensors)
 			0x10: Raw value of six-axis sensor (before calculation)
 			0x20: Temparature
 	DataType: Pointer to one 32-Bit enumeration value.
 		If pointer-value is not NULL, the function writes one of the following
 		codes for the data type of the measuring values in the value frame sent
 		by the GSV-8 (the values in the frame have all the same data type):
 		0x01: Data type sent by device is 16-Bit integer value in binary offset format (raw value)
 		0x02: Data type sent by device is 24-Bit integer value in binary offset format (raw value)
 		0x03: Data type sent by device is 32-Bit float value (IEEE754), scaled in physical units
 \return NumberOfMappedObjects: Number of value-objects in the measuring frame, Range: 1 to 16.
 	Or GSV_ERROR if function failed.
 If =GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 36
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getValObjectInfo(int ComNo, double* ScaleFactors, unsigned long* ObjMapping, int* DataType);

/*************************************************************************************
	Get Value Mapping Info
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Index:	0: number of mapped objects.
 		1..NumberOfMappedObjects: Get Info of corresponding Object in Value-Frame,
 		whereby 1: first Object in device value frame, which is at Object Index 0 of GSVread
 \return 	if Index=0: number of mapped objects (1..16) or =0: Mapping not present or npt supported by device
 		else if Index= 1..NumberOfMappedObjects:
 		ObjMapping: See description for GSV86getValObjectInfo above
 	 or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 38
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getValMapping(int ComNo, int Index);

/*************************************************************************************
	Set Value Mapping Info
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Index:	0: Set number of mapped objects (ObjMapping=1..16)
 		or clear to default (ObjMapping=0)
 		if 1..NumberOfMappedObjects: Set Info of corresponding Object in Value-Frame,
 		whereby 1: first Object in device value frame, which is at Object Index 0 of GSVread
 	ObjMapping: 
 		if Index=0: number of mapped objects (1..16)
 		or =0: Clear Mapping to default: Obj1..8= Channel 1..8, ValType= normal)
 		else if Index= 1..NumberOfMappedObjects:
 		See description for ObjMapping in GSV86getValObjectInfo above
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 
 Device access: 
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 TODO: KEIN Export. Nur gesamtes Mapping schreibend zulassen!
 **************************************************************************************/
int CALLTYP GSV86setValMapping(int ComNo, int Index, unsigned long ObjMapping);

/*************************************************************************************
	Select FT sensor calibration data array for reading
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \ArrNo: Index of array to select for reading with GSV86readFTsensorCalValue. Range: 0 to 4
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 164
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 05.10.2015 16:07
 **************************************************************************************/
int CALLTYP GSV86setFTarrayToRead(int ComNo, int ArrNo);

/*************************************************************************************
	Get single calibration value of six-axis sensor calibration
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \typ: One of theses:
#define SENSORCAL_TYP_MATRIX_NORM 1 Scaling of calibration matrix. ix must be =0
#define SENSORCAL_TYP_MATRIX 2 calibration matrix. ix: 0..35
#define SENSORCAL_TYP_OFFSET 3 mechanical offsets of sensor installation. ix: 0:X,1:Y,2:Z, in metres
#define SENSORCAL_TYP_MAXVAL 4 maximum values for the 6 outputs. ix:0..5:Fx,Fy,Fz,Mx,My,Mz
#define SENSORCAL_TYP_INSENS 5 input sensitivity of origin if calibration matrix. ix must be =0
#define SENSORCAL_TYP_ZEROVAL 6 No-load sensor deviations of the 6 inputs. ix: 0..5
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 40
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86readFTsensorCalValue(int ComNo, int typ, int ix, double* val);
 
/*************************************************************************************
	Get all calibration values for six-axis sensor calibration
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \ArrNo: 0x80: TEDS storage (coming hardware versions), Bits <6:0>: Calibrations structs index, if several
 sensors/calibration data sets are supported
 \SensorSerNo: pointer to String of 8 number digits: Sensor serial number will be written here
 \MatrixNorm: ptr to single double value: Scaling of calibration matrix will be written here
 \InSens: ptr to single double value: input sensitivity of origin if calibration matrix ill be written here
 \Matrix: ptr to array of 36 double values: Calibration matrix will be written, order: first row 0..5, 2nd row 6..11...
 \Offsets: ptr to array of 3 double values: mechanical offsets of sensor installation in mmetres. 0..2:Ox,Oy,Oz
 \MaxVals: ptr to array of 6 double values: maximum values for the 6 outputs. Order: 0..5: Fx,Fy,Fz,Mx,My,Mz
 \Zvals: ptr to array of 6 double values: No-load sensor deviations of the 6 inputs. Order: 0..5: Fx,Fy,Fz,Mx,My,Mz
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 42
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86readFTsensorCalArray(int ComNo,int ArrNo, char* SensorSerNo,
		double* MatrixNorm, double* InSens,double* Matrix,double* Offsets,double* MaxVals,double* Zvals);

/*************************************************************************************
	Set all calibration values for six-axis sensor calibration
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \ArrNo: 0x80: TEDS storage (coming hatdware versions), Bits <6:0>: Calibrations structs index, if several
 sensors/calibration data sets are supported
 \SensorSerNo: pointer to String of 8 number digits: Sensor serial number read from here
 \MatrixNorm: single double value: Scaling of calibration matrix
 \InSens: single double value: input sensitivity of origin if calibration matrix
 \Matrix: ptr to array of 36 double values: Calibration matrix will be written, order: first row 0..5, 2nd row 6..11...
 \Offsets: ptr to array of 3 double values: mechanical offsets of sensor installation in mmetres. 0..2:Ox,Oy,Oz
 \MaxVals: ptr to array of 6 double values: maximum values for the 6 outputs. Order: 0..5: Fx,Fy,Fz,Mx,My,Mz
 \Zvals: ptr to array of 6 double values: No-load sensor deviations of the 6 inputs. Order: 0..5: Fx,Fy,Fz,Mx,My,Mz
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 44
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86writeFTsensorCalArray(int ComNo, int ArrNo, const char* SensorSerNo,
		double MatrixNorm, double InSens, double* Matrix,double* Offsets,double* MaxVals, double* Zvals);
		
/*************************************************************************************
	Set mechanical offset values for six-axis sensor calibration
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \MemNo: 0x80: TEDS storage (coming hatdware versions), Bits <6:0>: Calibrations structs index, if several
 sensors/calibration data sets are supported
 \offsets: pointer to double array, which contain the three offsets values,
 	whwreby at index 0: offset in metres in X directin,
 	index 1: offset in metres in Y direction,
 	index 2: offset in metres in X directin.
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 45
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 25.04.2015 16:24
 **************************************************************************************/
int CALLTYP GSV86writeFTsensorGeoOffsets(int ComNo, int ArrNo, double* offsets);

/*************************************************************************************
	Read sensor serial number of six-axis sensor
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \ArrNo: 0x80: TEDS storage (coming hatdware versions), Bits <6:0>: Calibrations structs index, if several
 sensors/calibration data sets are supported
 \SensorSerNo: pointer to String of 8 number digits: Sensor serial number will be written here
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 46
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86readFTsensorSerNo(int ComNo, int ArrNo, char* SensorSerNo);

/*************************************************************************************
	Set all calibration values for six-axis sensor calibration
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \ArrNo: 0x80: TEDS storage (coming hatdware versions), Bits <6:0>: Calibrations structs index, if several
 sensors/calibration data sets are supported
 \DatFilePath: String (ptr) to full path of sensor calibration file: "<drive>:\\<path\\<name>.dat"
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 100
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86writeFTsensorFromFile(int ComNo, int ArrNo, const char* DatFilePath);

/*************************************************************************************
	Get Information about Six-axis calibration array data sets
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
     *MaxNumSupp: Pointer to int value, where the maximum number of storable six-axis arrays are written
     *ArrNumStored: Pointer to int value, where the number of stored six-axis-arrays are written
 \return: index of active six-axis calibration array (beginning with 0) or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 162
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getFTsensorCalArrayInfo(int ComNo, int* MaxNumSupp, int* ArrNumStored);

/*************************************************************************************
	Set active Six-axis calibration array
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
     ArrNo: Index of six-axis calibration array (beginning with 0) to activate. Range: 0 to 4.
 \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 163
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86setFTsensorActiveCalArray(int ComNo, int ArrNo);

/*************************************************************************************
	Erase last Six-axis calibration array
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 Remark: The 1st array (ArrNo=0) can't be erased,
 	so the minimum number of stored calibration arrays is 2
--------------------------------------------------------------------------------------
 OrdinalNo: 163
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86eraseFTsensorCalArray(int ComNo);

/*************************************************************************************
	Get Data rate
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return Measuring data rate or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 48
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
double CALLTYP GSV86getFrequency(int ComNo);

/*************************************************************************************
	Set Data rate
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 50
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86setFrequency(int ComNo, double frequency);

/*************************************************************************************
	Set Zero. Adjust internal offset values, so that measuring value becomes Zero.
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: if =0: Set all channels to zero. 1..8: Set specified channel to zero.
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 56
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86setZero(int ComNo, int Chan);

/*************************************************************************************
	Get input type and range, as actually active
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: Number of input channel, 1..8
 	Range: if not NULL: pointer to one variable of double, where the input range
 		(sensitivity) is written to. Physical unit of range depends on the 
 		Input Type: Bridge inputs (0..2): mV/V. Single ended (3): V
 		Temperature (4..5): range is meaningless (not applicable)
 \return Input Type, defined as follows:
 	#define INTYP_BRIDGE_US875 	0	Input-Type Bridge at Vexcitation=8.75V
	#define INTYP_BRIDGE_US5 	1	Input-Type Bridge at Vexcitation=5V
	#define INTYP_BRIDGE_US25 	2	Input-Type Bridge at Vexcitation=2.5V
	#define INTYP_SE10 		3	Input-Type single-endend +-10V
	#define INTYP_PT1000		4	Input-Type Temperature-Sensor PT1000
	#define INTYP_TEMP_K		5	Input-Type Temperature-Sensor Type-K
 	or GSV_ERROR if function failed.
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 64
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 11-18-2014
 **************************************************************************************/
int CALLTYP GSV86getInTypeRange(int ComNo, int Chan, double* Range);

/*************************************************************************************
	Get all available input types and ranges
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan:	Number of input channel, 1..8
 	Types: 	If not NULL: pointer to array of int, where the existent input types
 		are written to. Type definition: see GSV86setInType (InType)
 	Ranges: If not NULL: pointer to array of double, where the existent input ranges
 		(sensitivities) are written to. Meaning depends on corresponding InType,
 		which has the same index in InTypes array. See above.
 		Array sizes should be MAX_INPUT_TYPES_NUM
 \return Number of existent input types 
 	or GSV_ERROR if function failed.
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 66
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 11-18-2014
 **************************************************************************************/
int CALLTYP GSV86getAllInTypesRanges(int ComNo, int Chan, int* InTypes, double* Ranges);

/*************************************************************************************
	Set input type
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: Number of input channel, 1..8
 	InType: Input type, defined as follows:
 	#define INTYP_BRIDGE_US875 	0	Input-Type Bridge at Vexcitation=8,75V
	#define INTYP_BRIDGE_US5 	1	Input-Type Bridge at Vexcitation=5V
	#define INTYP_BRIDGE_US25 	2	Input-Type Bridge at Vexcitation=2,5V
	#define INTYP_SE10 		3	Input-Type single-endend +-10V
	#define INTYP_PT1000		4	Input-Type Temperature-Sensor PT1000
	#define INTYP_TEMP_K		5	Input-Type Temperature-Sensor Type-K
  \return 
 	Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 68
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 11-18-2014
 **************************************************************************************/
int CALLTYP GSV86setInType(int ComNo, int Chan, int InType);

/*************************************************************************************
	Read Offset Value defined by user
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: 1..8: Read offset of specified channel
 	*Offset: Pointer to double value, where the user offset is wriiten to, if returned GSV_OK.
 	This value is added by the device to every measuring value, if the device's
 	measuring value data type is DATATYP_FLOAT
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 72
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86readUserOffset(int ComNo, int Chan, double* Offset);

/*************************************************************************************
	Write Offset Value
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: if =0: Set offset of all channels to the same value. 1..8: Read offset of specified channel
 	Offset: Offset value, which is added by the device to every measuring value, if the device's
 	measuring value data type is DATATYP_FLOAT
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 74
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86writeUserOffset(int ComNo, int Chan, double Offset);

/*************************************************************************************
	Load Parameters from non-volatile memory
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	DataSetNo: =0: Load settings from previous power-on session
 		=1: Load factory default settings
 		=2..6: Load settings, which were previously stored by user
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 76
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86loadSettings(int ComNo, int DataSetNo);

/*************************************************************************************
	Store Parameters in non-volatile memory
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	DataSetNo: 2..6: Store settings at specified dataset
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 78
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86storeSettings(int ComNo, int DataSetNo);

/*************************************************************************************
	Get Analog output type and mode
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
	Chan: 1..8: Channel number of analog output to read type and mode.
	Type: Pointer, where Analog output type enum (see above) is written to.
 \return: Mode as defined above or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 112
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getAnalogOutType(int ComNo, int Chan, int *Type);
/*************************************************************************************
	Set Analog output type and mode
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
	Chan: 0..8: Channel number of analog output to change type and mode.
		A value of 0 means that all outputs are set to the same type/mode.
	Type: Analog output type enum as follows:
		#define AOUT_TYPE_0_10V 0	 0..10V 
		#define AOUT_TYPE_10_10V 1	 -10..10V
		#define AOUT_TYPE_0_5V 2	 0..5V
		#define AOUT_TYPE_5_5V 3	 -5..5V
		#define AOUT_TYPE_4_20A 4	 4..20mA
		#define AOUT_TYPE_0_20A 6	 0..20mA
	Mode: Flag value as follows:
		#define AOUT_ACTIVE_M_VALUES 0 Output is on and follows the corresponding
				measuring value input.
		#define AOUT_MODE_DIRECT 1 Output is on, but does NOT react on measuring values,
			but is direcly settable with GSV86writeAoutDirect
		#define AOUT_MODE_OFF 2 Output is off and high-impedance.
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 114
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86setAnalogOutType(int ComNo, int Chan, int Type, int Mode);


/*************************************************************************************
	Write Analog output offset value
--------------------------------------------------------------------------------------
Write Offset value of analog output.
This voltage (or current) then represents a measuring value =0.
The analog output scaling value is adjusted as follows: Scaling= FSval*(1-(Offset/100))
 \in ComNo: 	Number of Device Comport
	Chan: 1..8: Channel number of analog output to change offset
	Offset: Value in percentage of positive full-scale value FSval. Range: -60%..60% 
	FSval is:  Output type:	0 & 1: 	10V
				2 & 3: 	5V
				4:	12mA
				6:	10 mA
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 104
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86writeAnalogOutOffset(int ComNo, int Chan, double Offset);

/*************************************************************************************
	Read Analog output offset value
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
	Chan: 1..8: Channel number of offset value to read
	Offset: Pointer, where function will write the Offset value in percentage of
	positive full-scale value. See above.
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 102
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86readAnalogOutOffset(int ComNo, int Chan, double *Offset);


/*************************************************************************************
	Read Analog output scaling value
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
	Chan: 1..8: Channel number of scale value to read
	Scale: Pointer, where function will write the scaling value.
	This is a factor representing the deviation of the output range based on the type.
	A scaling value of 1.0 will result in the positive full-scale voltage or current
	at the output if the Offset is =0 and the measuring value is either
	the input full range value (based on the input type) or the sensor maximum value
	(with six-axis sensors).
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 106
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86readAnalogOutScale(int ComNo, int Chan, double *Scale);

/*************************************************************************************
	Write Analog output scaling value
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
	Chan: 1..8: Channel number of scale value to write
	Scale: Desired scaling value
	This is a factor representing the deviation of the output range based on the type.
	See above. 
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 108
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86writeAnalogOutScale(int ComNo, int Chan, double Scale);

/**************************************************************************************
	Set Analog output voltage / current directly by DAC code
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
	Chan: 1..8: Channel number of analog output to set
	Code: 16-Bit DAC code, nominally as follows:
	0x0000: -11 V for -10..10 and 0..10 V output type
		0 mA for current output
	0x8000: 0V for voltage output
	0xFFFF: 11 V or 5.5V for voltage, 24mA for current output
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 \remark: Corresponding analog output must be in direct mode. See GSV86setAnalogOutType
--------------------------------------------------------------------------------------
 OrdinalNo: 110
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86writeAoutDirect(int ComNo, int Chan, int Code);

/*************************************************************************************
	Get fixed unit number
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
	Chan: 1..8: Channel number of unit number to read
 \return Unit-number. For assignment of codes 0..UNIT_NO_MAX to unit itself, see manual.
 	special codes: 0x000000FF: User definable unit text 1 active
 			0x000000FE: User definable unit text 2 active
 	or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 80
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getUnitNo(int ComNo, int Chan);

/*************************************************************************************
	Set fixed unit number
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: If =0: Set unit-no. of all channels to the same value. 1..8: Set Unit-no specified channel
	UnitNo: Number of unit to set.
 	For assignment of codes 0..UNIT_NO_MAX to unit itself, see manual.
 	special codes: 0x000000FF: User definable unit text 1 active
 			0x000000FE: User definable unit text 2 active
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 	or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 82
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86setUnitNo(int ComNo, int Chan, int UnitNo);

/* Constants for GSV86getUnitText and GSV86setUnitText */
#define UNIT_WIDTH 8	/* maximum width of unit text array incl. termination*/
/* Bits<7:0> of Code parameter. Can be ORed with Bit<23:8> constants */
#define ACTIVE_UNIT_ANY 0x00 /*GSV86getUnitText: Read active unit. GSV86setUnitText: Set and activate any unit */
#define USER_UNIT_1 0x01 /*GSV86getUnitText: Read user defined unit string 1. 
			GSV86setUnitText: Set and activate user defined unit string 1. */
#define USER_UNIT_2 0x02 /*GSV86getUnitText: Read user defined unit string 2. 
			GSV86setUnitText: Set and activate user defined unit string 2. */
#define SET_FIXED_UNIT	0x10 /*GSV86setUnitText: Set and activate fixed unit (UnitNo set) */
#define WRITE_USER_UNIT_1 0x11 /*GSV86setUnitText: Write user unit string 1 (not activated) */
#define WRITE_USER_UNIT_2 0x12 /*GSV86setUnitText: Write user unit string 2 (not activated) */
/* Bits<23:0> of Code parameter. Can be ORed with Bit<7:0> constants */
#define ANSI_CODEPAGE 0x00000000 /* ANSI 8-Bit coded */
#define ASCII_ONLY	0x00000100 /* Use ASCII 7-Bit only */
#define DOS_CODEPAGE_437 0x0001B500 /* DOS/Windows Codepage 437 */
#define WIN_CODEPAGE_1252 0x0004E400 /* Windows Codepage 1252 */
/*************************************************************************************
	Get unit text string
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: 1..8: Channel number of active unit text to read
 	code: Control value, consisting of unit type (Bits <7:0> and code page value (Bits <23:8>)
		Bits <23:8>: Code page. Only used if unit set by UnitNo (Bits<7:0>=0). Supported values:
		ANSI_CODEPAGE =0x0000: ANSI 8-bit
		ASCII_ONLY 0x0001: Strictly 7-Bit ASCII only (micro sign ->'u', degree sign left away, per mille->0/00) 
		DOS_CODEPAGE_437 0x01B5 (437d): Windows/DOS codepage 437
		WIN_CODEPAGE_1252 0x04E4 (1252d): Windows codepage 1252
		Bits<7:0>: Unit type to read:
		ACTIVE_UNIT_ANY =0: Read active unit (as set by unit-no, see GSV86getUnitNo)
	      	USER_UNIT_1 =1: Read user-defined unit string number 1 (Chan ignored)
	      	USER_UNIT_2 =2: Read user-defined unit string number 2 (Chan ignored)
	UnitText: Poiner to char array: Unit-Text to read, ANSI-coded 
	Must be at least 8 chars in length
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 	or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 84
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getUnitText(int ComNo, int Chan, int Code, char* UnitText);

/*************************************************************************************
	Set unit text string
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
     Chan: If =0: Set unit of all channels to the same value. 1..8: Set Unit of specified channel
     code: Control value, consisting of unit type (Bits <7:0> and code page value (Bits <23:8>)
	Bits <23:8>: Code page for interpreting UnitText. Only used if Bits<3:0>=0. Supported values:
	ANSI_CODEPAGE =0x0000: ANSI 8-bit
	ASCII_ONLY 0x0001: Strictly 7-Bit ASCII only (micro sign ->'u', degree sign left away or ^, per mille->0/00) 
	DOS_CODEPAGE_437 0x01B5 (437d): Windows/DOS codepage 437
	WIN_CODEPAGE_1252 0x04E4 (1252d): Windows codepage 1252
	Bits<7:0>: Storing method:
	ACTIVE_UNIT_ANY =0x00: If unit text corresponds to an available fixed unit, that one is activated (UnitNo set accordingly).
	Otherwise, user-defined unit string is written to the device at Unit-Text 1 and activated (UnitNo set to 0xFF)
	USER_UNIT_1 =0x01: User-defined unit string is written to the device at Unit-Text 1 and activated (UnitNo set to 0xFF)
	USER_UNIT_2 =0x02: User-defined unit string is written to the device at Unit-Text 2 and activated (UnitNo set to 0xFE)
	SET_FIXED_UNIT =0x10: If unit text corresponds to an available fixed unit, that one is activated (UnitNo set accordingly).
	Otherwise, nothing is set and an error is triggered.
	WRITE_USER_UNIT_1 =0x11: User-defined unit string is written to the device at Unit-Text 1, but not activated (UnitNo not set)
	WRITE_USER_UNIT_2 =0x12: User-defined unit string is written to the device at Unit-Text 2 but not activated (UnitNo not set)
      UnitText: Poiner to string with Unit-Text to set
		Maximum text-length is 7 chars
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 \remark: There're only two user-defined unit strings avaliable on the device (length is up to 7 chars each),
 	 while the UnitNo is stored for each of the 8 input channels individually.
--------------------------------------------------------------------------------------
 OrdinalNo: 86
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86setUnitText(int ComNo, int Chan, int Code, char* UnitText);

/*************************************************************************************
	Get Digital Filter enabled / disabled
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: If =0: Get Filter On/Off of all channels. 1..8: Get Filter On/Off of specified channel
 	Type: 	=0=FILT_TYPE_IIR: Get on/off state for the IIR filter.
 		=0x80=FILT_TYPE_FIR: Get on/off state for the FIR filter.
 \return On/Off state(s): If Chan=0: On/Off state in Bits<7:0>, Bit=1: Filter enabled, =0: disabled;
 				   while bit 0 corresponds to channel 1, ..., bit 7 to channel 8
 			  If Chan = 1..8: Get Filter on/off state of specified channel:
 			  	=1=GSV_TRUE: Filter enabled, =0=GSV_OK: Filter disabled
 	or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 88
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getDfilterOnOff(int ComNo, int Chan, int Type);

/*************************************************************************************
	Enable / disable Digital Filter
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: If =0: Set Filter On/Off for all channels. 1..8: Set Filter On/Off for specified channel
 	Type: 	=0=FILT_TYPE_IIR: Set on/off state for the IIR filter.
 		=0x80=FILT_TYPE_FIR: Set on/off state for the FIR filter.
	OnOff: If Chan=0: On/Off state in Bits<7:0>, Bit=1: Filter enabled, =0: disabled;
 				   while bit 0 corresponds to channel 1, ..., bit 7 to channel 8
 		If Chan = 1..8: Set Filter on/off state for specified channel:
 			  	=1=GSV_TRUE: Filter enabled, =0=GSV_OK: Filter disabled
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 90
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86setDfilterOnOff(int ComNo, int Chan, int Type, int OnOff);

/*************************************************************************************
	Get Digital Filter Information
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: 1..8: Get Filter Info for specified channel
 	TypeIn: =0=FILT_TYPE_IIR: Get Filter Info for the IIR filter.
 		=0x80=FILT_TYPE_FIR: Get Filter Info for the FIR filter.
 \out
 	TypeOut: Type of filter. Bit7: =0: IIR, =1: FIR
 		Bits<6:4>: =0: Low pass, =1: high pass, =2: band pass, =3: band stop
 		Bits<3:0>: Filter order (as by now, 4 for IIR, 4..14 for FIR)
 		See constant macros above (FILT_TYPE_<I/F>IR_<LP/HP/BP/BS>)
	CutOff*: Pointer to double array of min. size=2. At array index 0, the lower -3dB Cutoff
		frequency will be written. With filter types Band pass and band stop,
		at array index 1, the higher -3dB Cutoff frequency will be written.
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 92
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getDfilterInfo(int ComNo, int Chan, int TypeIn, int* TypeOut, double* CutOff);

/*************************************************************************************
	Get Digital Filter Type and order
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: 1..8: Get Filter Type for specified channel
 	TypeIn: =0=FILT_TYPE_IIR: Get Filter Type for the IIR filter.
 		=0x80=FILT_TYPE_FIR: Get Filter Type for the FIR filter.
 \return
 	Type of filter. Bit7: =0: IIR, =1: FIR
 		Bits<6:4>: =0: Low pass, =1: high pass, =2: band pass, =3: band stop
 		Bits<3:0>: Filter order (as by now, 4 for IIR, 4..14 for FIR)
 		See constant macros above (FILT_TYPE_<I/F>IR_<LP/HP/BP/BS>)
 	or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 93
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getDfilterType(int ComNo, int Chan, int TypeIn);

/*************************************************************************************
	Get Digital Filter Coefficients
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: 1..8: Get Filter Coefficients for specified channel
 	Type: =0=FILT_TYPE_IIR: Get Filter Coefficients for the IIR filter.
 		=0x80=FILT_TYPE_FIR: Get Filter Coefficients for the FIR filter.
 	Coeff*: Pointer to double array of min. size =8. With IIR filter, at the first 5 places
 		the a coefficients a0..a4 will be stored, with a0 at index 0.
 		With FIR filter, the 8 FIR coefficients will be stored.
 	CoeffB*: Pointer to double array of min. size =4. Only with IIR filter, at the first 4 places
 		the b coefficients b0..b3 will be stored, with b0 at index 0. Can be NULL with FIR filter.
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 94
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getDfilterCoeff(int ComNo, int Chan, int Type, double* Coeff, double* CoeffB);

/*************************************************************************************
	Set Digital Filter Parameters
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: 0..8: If =0: Set Filter Params for all channels. Else: Set Filter Params for specified channel
 	Type: 	Type of filter. Bit7: =0: IIR, =1: FIR
 		Bits<6:4>: =0: Low pass, =1: high pass, =2: band pass, =3: band stop
 		Bits<3:0>: Filter order (as by now, 4 for IIR, 7 for FIR allowed)
 		See constant macros above (FILT_TYPE_<I/F>IR_<LP/HP/BP/BS>)
 	CutRatio*: Pointer to double array of min. size=2. At array index 0, the (lower) -3dB Cutoff
		frequency ratio fg/Fs is expected. With filter types Band pass and Band stop,
		at array index 1, the higher -3dB Cutoff frequency ratio fgo/Fs is expected.
 	Coeff*: Pointer to double array of min. size =5. With IIR filter,
 		the a coefficients a0..a4 are expected, with a0 at index 0.
 		With FIR filter, the first 4 FIR coefficients are expected, with a0=a7 at index 0, a1=a6 at ix.2 .. a3=a4 at ix.3.
 	CoeffB*: Pointer to double array of min. size =4. Only with IIR filter, at the first 4 places
 		the b coefficients b0..b3 are expected, with b0 at index 0. Can be NULL with FIR filter.
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 \remark: The effectivity and quality of the filter is NOT tested! The user is expected to have calculated
 	the coefficients appropriately in regard to the required cutoff frequency and filter type.
 	Wrong coeefficients can result in instable and unpredictable bahaviour of the filter, i.e.
 	erratic measuring values!
 	In order to get safe results, use GSV86calcSetDfilterParams instead!
--------------------------------------------------------------------------------------
 OrdinalNo: 96
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86setDfilterParams(int ComNo, int Chan, int Type, double* CutRatio, double* Coeff, double* CoeffB);

/*************************************************************************************
	Calculate and set Digital Filter Parameters
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: -1,0..8: If =0: Set Filter On/Off for all channels. Else: get Filter Coefficients for specified channel
 		If =-1: Do not write filter parameters to device. DLL stores Coefficients internally, e.g. for analysis (coming dll version)
 	Type: 	Type of filter. Bit7: =0: IIR, =1: FIR
 		Bits<6:4>: =0: Low pass, =1: high pass, =2: band pass, =3: band stop
 		Bits<3:0>: Filter order (as by now, 4 for IIR, 7 for FIR allowed)
 		See constant macros above (FILT_TYPE_<I/F>IR_<LP/HP/BP/BS>)
 	CutOff: -3dB cutoff frequency. With types band pass and band stop, this is the lower cut off frequency.
 	CutOffHi: Higher -3dB cutoff frequency. Only used for types band pass and band stop.
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 Additional possible error codes:
 #define DF_ERR_NO_CONVERGENCE 0x30000203 coefficient calculation failed to converge
 #define DF_ERR_COEFF_SUM_TOOBIG 0x30000208 coefficients are too big
--------------------------------------------------------------------------------------
 \remark: 
--------------------------------------------------------------------------------------
 OrdinalNo: 98
 Device access: Yes, if Chan > -1
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86calcSetDfilterParams(int ComNo, int Chan, int Type, double CutOff, double CutOffHi);

/*************************************************************************************
	Digital Filter time-domain simulation
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Analyze_Ftyp: one of
 		SIMUL_DFILT_FREQ_RESPONSE get Frequency response
 		SIMUL_DFILT_STEP_RESPONSE get step response
 		To simulate FIR filter, OR with FILT_TYPE_FIR
 	StartVal: First frequency if Analyze_Ftyp=SIMUL_DFILT_FREQ_RESPONSE
 		Start value (before step) if Analyze_Ftyp=SIMUL_DFILT_STEP_RESPONSE (standard step: =0)
 	EndVal: Last frequency if Analyze_Ftyp=SIMUL_DFILT_FREQ_RESPONSE
 		Step value (after step) if Analyze_Ftyp=SIMUL_DFILT_STEP_RESPONSE (standard step: =1)
 	Fa:	Sampling frequency = Data rate
 	Points: Number of simulated points (frequencies or samples, respective)
 	Filepath: Full path to file, where results are written to. File should not exist before;
 		otherwise, it will be overwritten.
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 Additional possible error codes:
 #define DF_ERR_NOT_INIT 0x30000201 GSV86calcSetDfilterParams not called before
 #define DF_ERR_OPT_WRONG 0x30000202 wrong parameters
 #define DF_ERR_NO_CONVERGENCE 0x30000203 coefficient calculation failed to converge
 #define DF_ERR_COEFF_SUM_TOOBIG 0x30000208 coefficients are too big
--------------------------------------------------------------------------------------
 \remark: GSV86calcSetDfilterParams must be called before.
 	There, Chan can be set to -1 for simulation only (no device access).
--------------------------------------------------------------------------------------
 OrdinalNo: 99
 Device access: No
---------------------------------------------------------------------------------------
 \revision date: 3-6-2015
 **************************************************************************************/
int CALLTYP GSV86simulateDfilter(int ComNo, int Analyze_Ftyp, double StartVal, double EndVal, double Fa, int Points, char* Filepath);

/*************************************************************************************
	Get device working hours
--------------------------------------------------------------------------------------
 \in 	ComNo: 	Number of Device Comport
 	Index: =0: Get absolute Device working hours (not resettable)
 		=1: Get relative (settable) device working hours
 \return: Hours, which the device was switched on or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 26-02-2015
 **************************************************************************************/
double CALLTYP GSV86readDeviceHours(int ComNo, int Index);

/*************************************************************************************
	Set device hours
--------------------------------------------------------------------------------------
 \in 	ComNo: 	Number of Device Comport
 	Hours: Hours to set. Device will increment value by minutes and store in non-volatile memory.
 \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 117
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 26-02-2015 
 **************************************************************************************/
int CALLTYP GSV86writeDeviceHours(int ComNo, double Hours);

/*************************************************************************************
	Get Threshold for the noise cut, which sets measuring values below this threshold
	(but above -1*threshold) to the zero value.
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: 1..8: Get noise cut thershold for specified channel
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getNoiseCutThreshold(int ComNo, int Chan, double* Thres);
 
/*************************************************************************************
	Set Threshold for the noise cut, which sets measuring values below this threshold
	(but above -1*threshold) to the zero value.
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Chan: 0..8: Set noise cut thershold for specified channel.
 		0 means: all channels to the same value
 	Thres: Noise cut thershold in percentage of the full scale range.
 		Value range is: 0.001% to 20%
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86setNoiseCutThreshold(int ComNo, int Chan, double Thres);

/*************************************************************************************
	Get Flag value of device capabilities
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return: Flags:
 	Bit 0: HAS_ADC Has analog-digital converter
 	Bit 1: HAS_ETHERCAT Has EtherCat fieldbus
 	Bit 2: HAS_LCD Has LC-Display
 	Bit 3: HAS_TEDS Has TEDS sensor reading capability
 	Bit 4: HAS_DIGI_IO Has digital inputs and outputs
 	Bit 6: HAS_ANALOG_OUT Has analog output(s)
 	Bit 7: HAS_SERIAL Has serial interface
 	Bit 8: HAS_FREQ_OUT Has frequency output
 	Bit 9: HAS_AIN_MCU Has Coprocessor for analog input
 	Bit 10: HAS_SIXAXIS Supports six-axis sensor
 	or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 122
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 10-31-2014
 **************************************************************************************/
int CALLTYP GSV86getSoftwareConfiguration(int ComNo);

/*************************************************************************************
	Set special property for measuring values
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	PropType: =0: Set special value properties off, so that normal mesuring mode is enabled again
	=1: Set simulated value on, so that all readouts of all channels
	become equal to half of the full-scale value ("calibration jump")
	\remark: This state is volatile (not saved in EEPROM memory)
	=2: Load Zero calibration values, so that measuring values give the
	no-load sensor deviation.
	=3: Load Zero calibration values of first six-axis sensor, so that measuring values give the
	(no-load) sensor deviation.
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 124
 Device access: Yes (Cmd. 0x35)
---------------------------------------------------------------------------------------
 \revision date: 3-9-2015 war GSV86setSimulatedValue
 19.05.2015 22:34 umbenannt zu GSV86setMeasValProperty !
 **************************************************************************************/
int CALLTYP GSV86setMeasValProperty(int ComNo, int PropType);

/*************************************************************************************
	Get value error information
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	Ix: =0: Get number of Error events stored in Memory as return value.
 		If >=1: First Error (number) is a recent one, stored in memory, accessible by index 1.
 		>=2: Error(s) stored in memory, accessible from index 2 on, up to <Number of Errors< + 1.
 	Ix=1: Get recent Error: Writes error flags to *ErrInfo and device hours, when error occurred to *ErrTime.
 	Ix= 2..<Number of errors +1>: get Error(s) stored in memory:
 		Writes error flags to *ErrInfo and device hours, when error occurred to *ErrTime.
 \return Number of errors stored, if Ix =0, otherwise:
 	Errortype:
 	#define VALERR_TYPE_SATURATED 1 Measuring value saturated
	#define VALERR_TYPE_MAX_EXCEED 2 For 6-axis sensors: Maximum exceedance
	#define VALERR_TYPE_SENSOR_BROKEN 3 Sensor or sensor cable broken
 	or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 126
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 09.04.2015 16:15
 **************************************************************************************/
int CALLTYP GSV86getValueError(int ComNo, int Ix, int* ErrInfo, double *ErrTime);

/*************************************************************************************
	Erase value error memory
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 128
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 09.04.2015 16:15
 **************************************************************************************/
int CALLTYP GSV86eraseValueErrMemory(int ComNo);

/*************************************************************************************
	Reset Error state
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 140
 Device access: Yes (Cmd. 0x00)
---------------------------------------------------------------------------------------
 \revision date: 09.04.2015 16:15
 **************************************************************************************/
int CALLTYP GSV86resetErrorState(int ComNo);

/*************************************************************************************
	Get analog filter cutoff frequency
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 CutOffFreq* pointer to double value where cutoff frequency of analog input filter is written to
 \return GSV_TRUE, if cutoff frequency is set by device automatically, according to the 
 data rate (see below).
 GSV_OK, if automatic filter setting is disabled or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 128
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 16.04.2015 12:12
 **************************************************************************************/
int CALLTYP GSV86readAnalogFilterCutOff(int ComNo, double* CutOffFreq);

/*************************************************************************************
	Set analog filter cutoff frequency
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 CutOffFreq Desired cutoff frequency of analog input filter.
 	Set to 0, to enable automatic cutoff frequency setting (accoring to data rate).
 	Otherwise, only 3 fixed cutoff frequency values will be set, closest to parameter CutOffFreq:
 	If CutOffFreq <= FDATA_MAX_FG28HZ: ANAFILT_LOW will be set, otherwise:
 	If CutOffFreq <= FDATA_MAX_FG1KHZ: ANAFILT_MID will be set. See macros above.
\return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 \return GSV_TRUE, if cutoff frequency is set by device automatically, according to the 
 data rate (see below).
 GSV_OK, if automatic filter setting is disabled or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 128
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 16.04.2015 12:12
 **************************************************************************************/
int CALLTYP GSV86writeAnalogFilterCutOff(int ComNo, double CutOffFreq);

/*************************************************************************************
	Read digital zero raw value
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 Chan: 1..8: channel to read zero value
 \return Offset-zero raw value or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 141
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 16.04.2015 12:12
 **************************************************************************************/
int CALLTYP GSV86readZeroValue(int ComNo, int Chan);

/*************************************************************************************
	Write digital zero raw value
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 Chan: 1..8: channel to write zero value
 zero: Zero raw value, represented as a signed integer value of 16 or 24 bits magnitude,
 	depending on the measuring value type
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 142
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 16.04.2015 12:12
 **************************************************************************************/
int CALLTYP GSV86writeZeroValue(int ComNo, int Chan, int zero);

/*************************************************************************************
	Get ID level, according to password / PIN set
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return ID level: 0: no password set
 		   >=8: User password set
 		   or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 143
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 16.04.2015 12:12
 **************************************************************************************/
int CALLTYP GSV86getIDlevel(int ComNo);

/*************************************************************************************
	Trigger sending of one measuring value frame
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 \remark: Retrieve measuring value frame with GSVread
--------------------------------------------------------------------------------------
 OrdinalNo: 144
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 16.04.2015 12:12
 **************************************************************************************/
int CALLTYP GSV86triggerValue(int ComNo);

/*************************************************************************************
	Get maximum and Minimum value
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 Chan: 0..8: Get maximum and Minimum value of specified channel
 		0 means: Get values of all measuring objects (8 channels, respective):
 		If =0: *MaxValue and *MinValue must point to array of (at least)
 		double[8] size
 *MaxValue: pointer to single value of double type (Chan>0), where maximum measuring
 	value will be written to.
 *MinValue: pointer to single value of double type (Chan>0), where minimum measuring
 	value will be written to.
\return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 \remark: Precondition: Maximum/Minimum Mode actvated in device: GSV86getModeMaxMin must
 	return GSV_TRUE
--------------------------------------------------------------------------------------
 OrdinalNo: 142
 Device access: Yes (Cmd 0x53)
---------------------------------------------------------------------------------------
 \revision date: 16.04.2015 12:12
 **************************************************************************************/
int CALLTYP GSV86getMaxMinValue(int ComNo, int Chan, double* MaxValue, double* MinValue);

/*************************************************************************************
	Clear maximum and Minimum value
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 Chan: 0..8: Channel to clear maximum and minimum value. 0: clear for all channels
 \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 148
 Device access: Yes (Cmd 0x3C)
---------------------------------------------------------------------------------------
 \revision date: 16.04.2015 12:12
 **************************************************************************************/
int CALLTYP GSV86clearMaxMinValue(int ComNo, int Chan);

/*************************************************************************************
	See, if command number (range) is available
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 CmdUp: Higher command number of command number range to check
 	(may be equal to CmdLo, if only one command is to be checked)
 CmdLo: Lower command number of command number range to check
  \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 146
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 16.04.2015 12:12
 **************************************************************************************/
int CALLTYP GSV86getIsCmdAvailable(int ComNo, int CmdUp, int CmdLo);

/*************************************************************************************
	Enable / disable write protection of device
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 OnOff: =0: Disable write protection, =1: Enable  write protection
  \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 150
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 16.04.2015 12:12
 **************************************************************************************/
int CALLTYP GSV86switchBlocking(int ComNo, int OnOff);

/*************************************************************************************
	Change User password
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 NewPW: Char-String to new user password. Must be 4 chars long.
  \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 \ pre-condition: Old user password given with GSV86setPassword
--------------------------------------------------------------------------------------
 OrdinalNo: 151
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 16.04.2015 12:12
 **************************************************************************************/
int CALLTYP GSV86changePassword(int ComNo, char* NewPW);

/*************************************************************************************
	Set User password
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 NewPW: Char-String to user password. Default is: "Beln"
  \return Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 52
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 18.06.2015 11:29
 **************************************************************************************/
int CALLTYP GSV86setPassword(int ComNo, char* password);
/*************************************************************************************
	Get digital IO direction
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	DIOgroup: The 16 digital IO lines are assigned to 4 groups, whose data direction
 		can only be changed for that group of 4 IO lines.
 		Assignment is as follows:
 		GroupNo		DIOno	BitNo in returnVal, if DIOgroup=0
 		1		1..4	0
 		2		5..8	1
 		3		9..12	2
 		4		13..16	3
 		If DIOgroup is =0, all 4 direchtions are returned in Bits>3:0>.
  \return: Data direction: GSV_TRUE (=1) for Input and GSV_OK (=0) for output
  or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 152
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 18.06.2015 11:29
 **************************************************************************************/
int CALLTYP GSV86getDIOdirection(int ComNo, int DIOgroup);

/*************************************************************************************
	Set digital IO direction
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	DIOgroup: See above.
 		If DIOgroup is =0, all 4 directions are set according to Bits<3:0> of Direction
 	Direction: =0 for output or =1 for input
  \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 153
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 18.06.2015 11:29
 **************************************************************************************/
int CALLTYP GSV86setDIOdirection(int ComNo, int DIOgroup, int Direction);

/*************************************************************************************
	Get digital IO type
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	DIOno: Number of digital IO line 1..16.
 	*AssignedChan: Pointer to int value, where the assigned channel 1..8 is written to, but only
 	if DIOtype= ThresholdSwitch (DIO_OUT_THRESHOLD_ANYVAL Bit set) or DIO_IN_TARE_SINGLE.
  \return DIOtype:
  	#define DIO_IN_GENERALPURPOSE 0x04
	#define DIO_IN_QEI_ANY 0x08
	#define DIO_IN_TARE_SINGLE 0x10
	#define DIO_IN_TARE_ALL 0x20
	#define DIO_IN_RESET_MAXMIN 0x40
	#define DIO_IN_TRIG_SEND_VAL 0x80
	#define DIO_IN_TRIG_SEND_MAXVAL 0x100
	#define DIO_IN_TRIG_SEND_MINVAL 0x200
	#define DIO_IN_TRIG_SEND_AVGVAL 0x400
	#define DIO_IN_TRIG_SEND_VAL_WHILE_HI 0x800
	#define DIO_OUT_GENERALPURPOSE 0x1000
	#define DIO_OUT_THRESHOLD_ANYVAL 0x10000
	#define DIO_OUT_THRESHOLD_MAXVAL 0x14000
	#define DIO_OUT_THRESHOLD_MINVAL 0x18000
	#define DIO_THRESHOLD_WINDOWCOMP_MASK 0x2000
	#define DIO_INVERT_MASK	0x800000
   or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 153
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 18.06.2015 11:29
 **************************************************************************************/
int CALLTYP GSV86getDIOtype(int ComNo, int DIOno, int* AssignedChan);

/*************************************************************************************
	Set digital IO type
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	DIOno: Number of digital IO line 0..16. 0: Set all DIO-no to the same type
 	DIOtype: See definition above
 	AssignedChan: Channel to apply DIO functionality, if
 	DIOtype= ThresholdSwitch (DIO_OUT_THRESHOLD_ANYVAL Bit set) or DIO_IN_TARE_SINGLE.
  \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 154
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 21.06.2015 10:53
 **************************************************************************************/
int CALLTYP GSV86setDIOtype(int ComNo, int DIOno, int DIOtype, int AssignedChan);

/*************************************************************************************
	Get digital IO level
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	DIOno: Number of digital IO line 0..16. 0: Get all 16 DIO levels, whereby
 	Bit0 of return value = DIOno 1.. Bit15= DIOno 16
  \return: DIO level: GSV_TRUE, if DIO level = high, GSV_OK, if level = low,
  or Bits<15:0> = all levels if DIOno=0 or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 /remark: DIO level is read independently of DIOtype or DIOdirection.
--------------------------------------------------------------------------------------
 OrdinalNo: 155
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 21.06.2015 10:53
 **************************************************************************************/
int CALLTYP GSV86getDIOlevel(int ComNo, int DIOno);

/*************************************************************************************
	Set digital out level
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	DIOno: Number of digital IO line 0..16. 0: Set all 16 DIO levels, whereby
 		Bit0 of DIOlevel = DIOno 1.. Bit15= DIOno 16
 	DIOlevel: IO level to set: 1= high, 0=low or all 16 lines in Bits<15:0>
  \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 /remark: DIO level is set only if corresponding DIOtype= DIO_OUT_GENERALPURPOSE.
 Otherwise, if DIOno>0, the function returns GSV_ERROR (LastError=ERR_PAR_NOFIT_SETTINGS)
--------------------------------------------------------------------------------------
 OrdinalNo: 156
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 21.06.2015 10:53
 **************************************************************************************/
int CALLTYP GSV86setDoutLevel(int ComNo, int DIOno, int DIOlevel);

/*************************************************************************************
	Get digital-out threshold of threshold switch
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	DIOno: Number of digital IO line 1..16.
 	*ThresUp: Pointer to double value, whrere upper threshold is written to
 	*ThresDown: Pointer to double value, whrere lower threshold is written to
  \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 157
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 21.06.2015 10:53
 **************************************************************************************/
int CALLTYP GSV86getDoutThreshold(int ComNo, int DIOno, double* ThresUp, double* ThresDown);

/*************************************************************************************
	Set digital-out threshold of threshold switch
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	DIOno: Number of digital IO line 1..16.
 	ThresUp: Upper threshold of thershold switch
 	ThresDown: Lower threshold of thershold switch
  \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 \remark: ThresUp must be greater or equal than ThresDown
--------------------------------------------------------------------------------------
 OrdinalNo: 158
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 21.06.2015 10:53
 **************************************************************************************/
int CALLTYP GSV86setDoutThreshold(int ComNo, int DIOno, double ThresUp, double ThresDown);

/*************************************************************************************
	Get initial digital out level
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	DIOno: Number of digital IO line 0..16. 0: Get all 16 DO init levels, whereby
 	Bit0 of return value = DIOno 1.. Bit15= DIOno 16
  \return: DO init level: GSV_TRUE, if DO init level = high, GSV_OK, if level = low,
  or Bits<15:0> = all levels if DIOno=0 or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 /remark: DIO level is read independently of DIOtype or DIOdirection.
--------------------------------------------------------------------------------------
 OrdinalNo: 160
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 01.07.2015 18:39
 **************************************************************************************/
int CALLTYP GSV86getDoutInitLevel(int ComNo, int DIOno);

/*************************************************************************************
	Set initial digital out level
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 	DIOno: Number of digital IO line 0..16. 0: Set all 16 DIO levels, whereby
 		Bit0 of DIOlevel = DIOno 1.. Bit15= DIOno 16
 	DOInitLevel: Default out level to set: 1= high, 0=low or all 16 lines in Bits<15:0>
  \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
 /remark: Default out level is stored for corresponding DIOno(s), regardless of its type or invert state.
 This level is set to the corresponding DIO output if:
 1. The corresponding DIOtype is one of the output types
 2. DIO initialization is called. That happens at boot-up, at type or direction changing
 and at parameter loading
--------------------------------------------------------------------------------------
 OrdinalNo: 161
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 21.06.2015 10:53
 **************************************************************************************/
int CALLTYP GSV86setDoutInitLevel(int ComNo, int DIOno, int DOInitLevel);

/*************************************************************************************
	Get maximum and minimum possible data frequency
--------------------------------------------------------------------------------------
 \in ComNo: 	Number of Device Comport
 *DrateMax: pointer to double value, where maximum data frequency is written to
 *DrateMin: pointer to double value, where minimum data frequency is written to
  \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 164
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 18.08.2015 14:10
 **************************************************************************************/
int CALLTYP GSV86getDataRateRange(int ComNo, double* DrateMax, double* DrateMin);

/********************************************************************************************
	Get CAN / CANopen settings
---------------------------------------------------------------------------------------------
	\in ComNo: 	Number of Device Comport
	    Index:  =0: Command ID GSV86-CAN protocol
		Index:  =1: Command-Answer ID GSV86-CAN protocol
		Index:  =2: Value-Frame ID GSV86-CAN protocol
		Index:  =3: Multicast ID GSV86-CAN protocol
		Index:  =4: CAN-Baudrate in Bits/s (both CAN protocols)
		Index:	=5: Flags. Bit 1: CAN appl. layer protocol: =0: GSV86-CAN protocol
								=1: CANopen
				Bit 0: =0: CAN interface is switched on
					=1: CAN interface is switched off
		Index: =6:	CANopen NodeID (range: 1..0x7F)
	\out *setting. Pointer to value, where setting (according to Index) is written to
 \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 167
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 24.11.2015 12:45
 **************************************************************************************/
int CALLTYP GSV86readCANsettings(int ComNo, int Index, int* setting);

/********************************************************************************************
	Set CAN / CANopen settings
---------------------------------------------------------------------------------------------
	\in ComNo: 	Number of Device Comport
	    Index:  =0: Command ID GSV86-CAN protocol
		Index:  =1: Command-Answer ID GSV86-CAN protocol
		Index:  =2: Value-Frame ID GSV86-CAN protocol
		Index:  =3: Multicast ID GSV86-CAN protocol
		Index:  =4: CAN-Baudrate in Bits/s (both CAN protocols)
		Index:	=5: Flags. Bit 1: CAN appl. layer protocol: =0: GSV86-CAN protocol
								=1: CANopen
				Bit 0: =0: CAN interface is switched on
					=1: CAN interface is switched off
		Index: =6:	CANopen NodeID (range: 1..0x7F)
	setting value, according to Index
 \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 168
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 24.11.2015 12:45
 **************************************************************************************/
int CALLTYP GSV86setCANsettings(int ComNo, int Index, int setting);

/********************************************************************************************
	Get CAN / CANopen On / Off state
---------------------------------------------------------------------------------------------
	\in ComNo: 	Number of Device Comport
	\out *CANappProt. Pointer to value, where application protocol info is written to:
		=0 for proprietary (ME-Systeme) CAN "serial" protokol
		=1 for stadartized CANopen protocol
 \return: GSV_TRUE if CAN/CANopen is on (enabled), GSV_OK is it is off (disabled)
	 or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 169
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 02.12.2015 12:32
 **************************************************************************************/
int CALLTYP GSV86getCANonOff(int ComNo, int* CANappProt);

/********************************************************************************************
 Switch CAN / CANopen on or off
---------------------------------------------------------------------------------------------
	\in ComNo: 	Number of Device Comport
		OnOff: =0: Switch CAN/CANopen off
				=1: Switch CAN/CANopen on
 \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 170
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 02.12.2015 12:32
 **************************************************************************************/
int CALLTYP GSV86setCANonOff(int ComNo, int OnOff);

/* Interface descriptoion / settings */
/********************************************************************************************
 Get Interface Setting Value
---------------------------------------------------------------------------------------------
	\in ComNo: 	Number of Device Comport
	    Ix: index in linked list of interface descriptors/settings:
	    	if Ix = 0..(Number of interfaces - 1) =Interface Number: Basic settings, ApplEnum set
	 \out Next: Next index in linked list of interface descriptors/settings of the same interface
	 	if =0: End of list
	 	Data: Data read. if Ix= Interface Number: Flag value. Else: Interpretation according to return value
	 	ApplEnum: If Index < (Number of interfaces): Enumerator of application interface
	 	Writable: Function writes 1, if value is writable (with GSV86writeInterfaceSetting), otherwise 0
 \return: if Ix= Interface Number: Enumerator of physical interface:
 
 	  If Index >= (Number of interfaces): Type of Data:
 	         
 or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 172
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 24.01.2016 18:39
 **************************************************************************************/
int CALLTYP GSV86readInterfaceSetting(int ComNo, int Ix, int* Next, unsigned long* Data, int* ApplEnum, int* Writable);

/********************************************************************************************
 Get basic Interface Settings of all Interfaces or of interface actually communicating
---------------------------------------------------------------------------------------------
	\in ComNo: 	Number of Device Comport
	ActIntf: =0 get List of all Interfaces, =1: Get Actual Interface settings
	\out:
	 PhysEnums: ActIntf=1: IntfNo values written, else 1 value: Physical type enum, Index= Inteface-No <- OK? BESSER INTNO_USB=0 setzen?! Klren!
	 ApplEnums: IntfNo values written, else 1 value: Application Protocol Enum
	Flags: IntfNo values written, else 1 value: 
	
 \return: if ActIntf=1: Number of acual Interface
 	if ActIntf=0: Number of Interfaces present =Number of values written in Flags, PhysEnums and ApplEnums Arrays
 or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 173
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 24.01.2016 18:40
 **************************************************************************************/
int CALLTYP GSV86readBasicInterfSettings(int ComNo, int ActIntf, int* PhysEnums, int* ApplEnums, int* Flags);

/********************************************************************************************
 Get all Interface Settings of a particular interface
---------------------------------------------------------------------------------------------
	\in ComNo: 	Number of Device Comport
	     IntfNo: : Interface number: 0..Number of interfaces-1
	 \out IntfEnums: Always 2 values written: IntfEnums[0]: Physical type enum,
	 					IntfEnums[1]: Application type enum
	 	Dtypes: Array with all extended settings written, except baud rates.  =0 basic flag value
	 			>0: Type enumerator for Data meaning
	 	dat: Data content array. Interpretation according to Dtypes at same index.
	 	bdList: Array with all baudrates settings written [Bits/s]. bdList[0]: actual baud rate set.
	 	bdNum: value that holds number of baud rates written to bdList. bdNum-1 =Number of available baud rates
	\remark: Array size for Dtypes, dat and bdList won't ever exceed 256 Bytes. Just allocate 256 values.
 \return: Number of values written to dat and Dtypes
 or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 174
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 24.01.2016 18:40
 **************************************************************************************/
int CALLTYP GSV86readAllInterfSettings(int ComNo, int IntNo, int* IntfEnums, int* Dtypes, int* Data, int* BdList, int* BdNum);

/********************************************************************************************
 Write Interface Setting Value
---------------------------------------------------------------------------------------------
	\in ComNo: 	Number of Device Comport
	     IntfNo: : 
	    Ix: index in linked list of interface descriptors/settings:
	    	if Ix = 0..(Number of interfaces - 1) =Interface Number: Basic settings
	    Data: if Ix = 0..(Number of interfaces - 1): Flag value
	    		Else: Value, according to Type of Data (e.g. read with GSV86readInterfaceSetting)
 \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 176
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 24.01.2016 18:40
 **************************************************************************************/
int CALLTYP GSV86writeInterfaceSetting(int ComNo, int Ix, unsigned long Data);

/********************************************************************************************
 Switch interface on or off
---------------------------------------------------------------------------------------------
	\in ComNo: 	Number of Device Comport
	     IntfNo: Number of Interface 
	    OnOff: =1 switch on, =0: switch off
 \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 177
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 24.01.2016 18:41
 **************************************************************************************/
int CALLTYP GSV86setInterfaceOnOff(int ComNo, int IntNo, int OnOff);

/********************************************************************************************
 Write baud rate
---------------------------------------------------------------------------------------------
	\in ComNo: 	Number of Device Comport
	     IntfNo: Number of Interface 
	    Baud: baud rate in Bits/s
 \return: Simple errorcode: GSV_OK,if successful or GSV_ERROR if function failed or GSV_ERROR if function failed
 If GSV_ERROR, more detailed error information ca be retrieved with GSV86getLastProtocollError.
--------------------------------------------------------------------------------------
 OrdinalNo: 178
 Device access: Yes
---------------------------------------------------------------------------------------
 \revision date: 24.01.2016 18:41
 **************************************************************************************/
int CALLTYP GSV86writeInterfaceBaud(int ComNo, int IntNo, int Baud);

int CALLTYP GSV86MEwriteCal(int ComNo, int Chan, int ix, double cal);
int CALLTYP GSV86readCal(int ComNo, int Chan, int ix, double* cal);
int CALLTYP GSV86MEwriteInputRange(int ComNo, int Chan, int type, double range);
int CALLTYP MEgsv86setSerialNo(int ComNo, int SerNo);

#ifdef __cplusplus
}
#endif